==> hs-cairo-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/cairo-0.12.0/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.12.0
id: cairo-0.12.0-0298aadd5c50de52030d550500daacb0

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/cairo-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/cairo-0.12.0
              /usr/local/lib
hs-libraries: HScairo-0.12.0
extra-libraries: z cairo
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/cairo
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng
includes:
depends: array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         haskell98-1.1.0.1-d297a29bdc63fd1be05662f1882b09e7
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/cairo-0.12.0/html/cairo.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/cairo-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-cairo-0.12.2.tbz: lib/ghc-7.0.4/cabal/cairo-0.12.2/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.12.2
id: cairo-0.12.2-3c2fec1f88a91352e69551a3e4e32b3e

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/cairo-0.12.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/cairo-0.12.2
              /usr/local/lib
hs-libraries: HScairo-0.12.2
extra-libraries: z cairo
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/cairo
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/cairo-0.12.2/html/cairo.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/cairo-0.12.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
